# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_volatility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDsystemathics/apis/services/daily_analytics/v1/daily_volatility.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xb2\x01\n\x16\x44\x61ilyVolatilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"(\n\x17\x44\x61ilyVolatilityResponse\x12\r\n\x05value\x18\x01 \x01(\x01\x32\xbb\x01\n\x16\x44\x61ilyVolatilityService\x12\xa0\x01\n\x0f\x44\x61ilyVolatility\x12\x45.systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest\x1a\x46.systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponseb\x06proto3')



_DAILYVOLATILITYREQUEST = DESCRIPTOR.message_types_by_name['DailyVolatilityRequest']
_DAILYVOLATILITYRESPONSE = DESCRIPTOR.message_types_by_name['DailyVolatilityResponse']
DailyVolatilityRequest = _reflection.GeneratedProtocolMessageType('DailyVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVOLATILITYREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyVolatilityRequest)
  })
_sym_db.RegisterMessage(DailyVolatilityRequest)

DailyVolatilityResponse = _reflection.GeneratedProtocolMessageType('DailyVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVOLATILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyVolatilityResponse)
  })
_sym_db.RegisterMessage(DailyVolatilityResponse)

_DAILYVOLATILITYSERVICE = DESCRIPTOR.services_by_name['DailyVolatilityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYVOLATILITYREQUEST._serialized_start=223
  _DAILYVOLATILITYREQUEST._serialized_end=401
  _DAILYVOLATILITYRESPONSE._serialized_start=403
  _DAILYVOLATILITYRESPONSE._serialized_end=443
  _DAILYVOLATILITYSERVICE._serialized_start=446
  _DAILYVOLATILITYSERVICE._serialized_end=633
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/splits.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/corporate_actions/v1/splits.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x95\x01\n\rSplitsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"V\n\x0eSplitsResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.corporate_actions.v1.Split\"_\n\x05Split\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x12\n\nnew_shares\x18\x02 \x01(\x01\x12\x12\n\nold_shares\x18\x03 \x01(\x01\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x9b\x01\n\rSplitsService\x12\x89\x01\n\x06Splits\x12>.systemathics.apis.services.corporate_actions.v1.SplitsRequest\x1a?.systemathics.apis.services.corporate_actions.v1.SplitsResponseb\x06proto3')



_SPLITSREQUEST = DESCRIPTOR.message_types_by_name['SplitsRequest']
_SPLITSRESPONSE = DESCRIPTOR.message_types_by_name['SplitsResponse']
_SPLIT = DESCRIPTOR.message_types_by_name['Split']
SplitsRequest = _reflection.GeneratedProtocolMessageType('SplitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPLITSREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.SplitsRequest)
  })
_sym_db.RegisterMessage(SplitsRequest)

SplitsResponse = _reflection.GeneratedProtocolMessageType('SplitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPLITSRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.SplitsResponse)
  })
_sym_db.RegisterMessage(SplitsResponse)

Split = _reflection.GeneratedProtocolMessageType('Split', (_message.Message,), {
  'DESCRIPTOR' : _SPLIT,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.splits_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Split)
  })
_sym_db.RegisterMessage(Split)

_SPLITSSERVICE = DESCRIPTOR.services_by_name['SplitsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SPLITSREQUEST._serialized_start=241
  _SPLITSREQUEST._serialized_end=390
  _SPLITSRESPONSE._serialized_start=392
  _SPLITSRESPONSE._serialized_end=478
  _SPLIT._serialized_start=480
  _SPLIT._serialized_end=575
  _SPLITSSERVICE._serialized_start=578
  _SPLITSSERVICE._serialized_end=733
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJsystemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xf3\x01\n\x19IntradayVolatilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"+\n\x1aIntradayVolatilityResponse\x12\r\n\x05value\x18\x01 \x01(\x01\x32\xcd\x01\n\x19IntradayVolatilityService\x12\xaf\x01\n\x12IntradayVolatility\x12K.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest\x1aL.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponseb\x06proto3')



_INTRADAYVOLATILITYREQUEST = DESCRIPTOR.message_types_by_name['IntradayVolatilityRequest']
_INTRADAYVOLATILITYRESPONSE = DESCRIPTOR.message_types_by_name['IntradayVolatilityResponse']
IntradayVolatilityRequest = _reflection.GeneratedProtocolMessageType('IntradayVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest)
  })
_sym_db.RegisterMessage(IntradayVolatilityRequest)

IntradayVolatilityResponse = _reflection.GeneratedProtocolMessageType('IntradayVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse)
  })
_sym_db.RegisterMessage(IntradayVolatilityResponse)

_INTRADAYVOLATILITYSERVICE = DESCRIPTOR.services_by_name['IntradayVolatilityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYVOLATILITYREQUEST._serialized_start=281
  _INTRADAYVOLATILITYREQUEST._serialized_end=524
  _INTRADAYVOLATILITYRESPONSE._serialized_start=526
  _INTRADAYVOLATILITYRESPONSE._serialized_end=569
  _INTRADAYVOLATILITYSERVICE._serialized_start=572
  _INTRADAYVOLATILITYSERVICE._serialized_end=777
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+systemathics/apis/type/shared/v1/keys.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"V\n\x03Key\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\r\n\x05value\x18\x02 \x01(\r\"=\n\x04Keys\x12\x35\n\x06values\x18\x01 \x03(\x0b\x32%.systemathics.apis.type.shared.v1.Keyb\x06proto3')



_KEY = DESCRIPTOR.message_types_by_name['Key']
_KEYS = DESCRIPTOR.message_types_by_name['Keys']
Key = _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {
  'DESCRIPTOR' : _KEY,
  '__module__' : 'systemathics.apis.type.shared.v1.keys_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Key)
  })
_sym_db.RegisterMessage(Key)

Keys = _reflection.GeneratedProtocolMessageType('Keys', (_message.Message,), {
  'DESCRIPTOR' : _KEYS,
  '__module__' : 'systemathics.apis.type.shared.v1.keys_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Keys)
  })
_sym_db.RegisterMessage(Keys)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KEY._serialized_start=132
  _KEY._serialized_end=218
  _KEYS._serialized_start=220
  _KEYS._serialized_end=281
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_prices.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/daily/v1/daily_prices.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xae\x01\n\x12\x44\x61ilyPricesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"T\n\x13\x44\x61ilyPricesResponse\x12=\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32/.systemathics.apis.services.daily.v1.DailyPrice\"[\n\nDailyPrice\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x97\x01\n\x12\x44\x61ilyPricesService\x12\x80\x01\n\x0b\x44\x61ilyPrices\x12\x37.systemathics.apis.services.daily.v1.DailyPricesRequest\x1a\x38.systemathics.apis.services.daily.v1.DailyPricesResponseb\x06proto3')



_DAILYPRICESREQUEST = DESCRIPTOR.message_types_by_name['DailyPricesRequest']
_DAILYPRICESRESPONSE = DESCRIPTOR.message_types_by_name['DailyPricesResponse']
_DAILYPRICE = DESCRIPTOR.message_types_by_name['DailyPrice']
DailyPricesRequest = _reflection.GeneratedProtocolMessageType('DailyPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesRequest)
  })
_sym_db.RegisterMessage(DailyPricesRequest)

DailyPricesResponse = _reflection.GeneratedProtocolMessageType('DailyPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesResponse)
  })
_sym_db.RegisterMessage(DailyPricesResponse)

DailyPrice = _reflection.GeneratedProtocolMessageType('DailyPrice', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPrice)
  })
_sym_db.RegisterMessage(DailyPrice)

_DAILYPRICESSERVICE = DESCRIPTOR.services_by_name['DailyPricesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYPRICESREQUEST._serialized_start=223
  _DAILYPRICESREQUEST._serialized_end=397
  _DAILYPRICESRESPONSE._serialized_start=399
  _DAILYPRICESRESPONSE._serialized_end=483
  _DAILYPRICE._serialized_start=485
  _DAILYPRICE._serialized_end=576
  _DAILYPRICESSERVICE._serialized_start=579
  _DAILYPRICESSERVICE._serialized_end=730
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/sampling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v1/sampling.proto\x12 systemathics.apis.type.shared.v1*\xc0\x01\n\x08Sampling\x12\x18\n\x14SAMPLING_UNSPECIFIED\x10\x00\x12\x17\n\x13SAMPLING_ONE_MINUTE\x10\x01\x12\x18\n\x14SAMPLING_FIVE_MINUTE\x10\x02\x12\x17\n\x13SAMPLING_TEN_MINUTE\x10\x03\x12\x1b\n\x17SAMPLING_FIFTEEN_MINUTE\x10\x04\x12\x1a\n\x16SAMPLING_THIRTY_MINUTE\x10\x05\x12\x15\n\x11SAMPLING_ONE_HOUR\x10\x06\x62\x06proto3')

_SAMPLING = DESCRIPTOR.enum_types_by_name['Sampling']
Sampling = enum_type_wrapper.EnumTypeWrapper(_SAMPLING)
SAMPLING_UNSPECIFIED = 0
SAMPLING_ONE_MINUTE = 1
SAMPLING_FIVE_MINUTE = 2
SAMPLING_TEN_MINUTE = 3
SAMPLING_FIFTEEN_MINUTE = 4
SAMPLING_THIRTY_MINUTE = 5
SAMPLING_ONE_HOUR = 6


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAMPLING._serialized_start=86
  _SAMPLING._serialized_end=278
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDsystemathics/apis/services/intraday_analytics/v1/intraday_macd.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\x8a\x02\n\x13IntradayMacdRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0c\n\x04long\x18\x04 \x01(\x05\x12\r\n\x05short\x18\x05 \x01(\x05\x12\x12\n\nadjustment\x18\x06 \x01(\x08\"h\n\x14IntradayMacdResponse\x12P\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.intraday_analytics.v1.IntradayMacdData\"|\n\x10IntradayMacdData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04macd\x18\x03 \x01(\x01\x12\r\n\x05short\x18\x04 \x01(\x01\x12\x0c\n\x04long\x18\x05 \x01(\x01\x32\xb5\x01\n\x13IntradayMacdService\x12\x9d\x01\n\x0cIntradayMacd\x12\x45.systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest\x1a\x46.systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponseb\x06proto3')



_INTRADAYMACDREQUEST = DESCRIPTOR.message_types_by_name['IntradayMacdRequest']
_INTRADAYMACDRESPONSE = DESCRIPTOR.message_types_by_name['IntradayMacdResponse']
_INTRADAYMACDDATA = DESCRIPTOR.message_types_by_name['IntradayMacdData']
IntradayMacdRequest = _reflection.GeneratedProtocolMessageType('IntradayMacdRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest)
  })
_sym_db.RegisterMessage(IntradayMacdRequest)

IntradayMacdResponse = _reflection.GeneratedProtocolMessageType('IntradayMacdResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse)
  })
_sym_db.RegisterMessage(IntradayMacdResponse)

IntradayMacdData = _reflection.GeneratedProtocolMessageType('IntradayMacdData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDDATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdData)
  })
_sym_db.RegisterMessage(IntradayMacdData)

_INTRADAYMACDSERVICE = DESCRIPTOR.services_by_name['IntradayMacdService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYMACDREQUEST._serialized_start=308
  _INTRADAYMACDREQUEST._serialized_end=574
  _INTRADAYMACDRESPONSE._serialized_start=576
  _INTRADAYMACDRESPONSE._serialized_end=680
  _INTRADAYMACDDATA._serialized_start=682
  _INTRADAYMACDDATA._serialized_end=806
  _INTRADAYMACDSERVICE._serialized_start=809
  _INTRADAYMACDSERVICE._serialized_end=990
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/constraints.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import time_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_time__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/type/shared/v1/constraints.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/dayofweek.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a\x34systemathics/apis/type/shared/v1/time_interval.proto\"\xf7\x01\n\x0b\x43onstraints\x12\x46\n\x0e\x64\x61te_intervals\x18\x01 \x03(\x0b\x32..systemathics.apis.type.shared.v1.DateInterval\x12\x46\n\x0etime_intervals\x18\x02 \x03(\x0b\x32..systemathics.apis.type.shared.v1.TimeInterval\x12)\n\x0e\x65xcluded_dates\x18\x03 \x03(\x0b\x32\x11.google.type.Date\x12-\n\rexcluded_days\x18\x04 \x03(\x0e\x32\x16.google.type.DayOfWeekb\x06proto3')



_CONSTRAINTS = DESCRIPTOR.message_types_by_name['Constraints']
Constraints = _reflection.GeneratedProtocolMessageType('Constraints', (_message.Message,), {
  'DESCRIPTOR' : _CONSTRAINTS,
  '__module__' : 'systemathics.apis.type.shared.v1.constraints_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Constraints)
  })
_sym_db.RegisterMessage(Constraints)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONSTRAINTS._serialized_start=250
  _CONSTRAINTS._serialized_end=497
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/mappings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v1/mappings.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\"\x97\x01\n\x07Mapping\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x34\n\x04memo\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.Memo\x12\x14\n\x0c\x65vent_source\x18\x03 \x01(\r\"D\n\x08Mappings\x12\x38\n\x05table\x18\x01 \x03(\x0b\x32).systemathics.apis.type.shared.v1.Mappingb\x06proto3')



_MAPPING = DESCRIPTOR.message_types_by_name['Mapping']
_MAPPINGS = DESCRIPTOR.message_types_by_name['Mappings']
Mapping = _reflection.GeneratedProtocolMessageType('Mapping', (_message.Message,), {
  'DESCRIPTOR' : _MAPPING,
  '__module__' : 'systemathics.apis.type.shared.v1.mappings_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Mapping)
  })
_sym_db.RegisterMessage(Mapping)

Mappings = _reflection.GeneratedProtocolMessageType('Mappings', (_message.Message,), {
  'DESCRIPTOR' : _MAPPINGS,
  '__module__' : 'systemathics.apis.type.shared.v1.mappings_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Mappings)
  })
_sym_db.RegisterMessage(Mappings)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MAPPING._serialized_start=182
  _MAPPING._serialized_end=333
  _MAPPINGS._serialized_start=335
  _MAPPINGS._serialized_end=403
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_bars.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/services/daily/v1/daily_bars.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xac\x01\n\x10\x44\x61ilyBarsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"P\n\x11\x44\x61ilyBarsResponse\x12;\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32-.systemathics.apis.services.daily.v1.DailyBar\"\x82\x01\n\x08\x44\x61ilyBar\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x0c\n\x04open\x18\x02 \x01(\x01\x12\x0c\n\x04high\x18\x03 \x01(\x01\x12\x0b\n\x03low\x18\x04 \x01(\x01\x12\r\n\x05\x63lose\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x03\x12\r\n\x05score\x18\x07 \x01(\x01\x32\x8e\x01\n\x10\x44\x61ilyBarsService\x12z\n\tDailyBars\x12\x35.systemathics.apis.services.daily.v1.DailyBarsRequest\x1a\x36.systemathics.apis.services.daily.v1.DailyBarsResponseb\x06proto3')



_DAILYBARSREQUEST = DESCRIPTOR.message_types_by_name['DailyBarsRequest']
_DAILYBARSRESPONSE = DESCRIPTOR.message_types_by_name['DailyBarsResponse']
_DAILYBAR = DESCRIPTOR.message_types_by_name['DailyBar']
DailyBarsRequest = _reflection.GeneratedProtocolMessageType('DailyBarsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBARSREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyBarsRequest)
  })
_sym_db.RegisterMessage(DailyBarsRequest)

DailyBarsResponse = _reflection.GeneratedProtocolMessageType('DailyBarsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBARSRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyBarsResponse)
  })
_sym_db.RegisterMessage(DailyBarsResponse)

DailyBar = _reflection.GeneratedProtocolMessageType('DailyBar', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBAR,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyBar)
  })
_sym_db.RegisterMessage(DailyBar)

_DAILYBARSSERVICE = DESCRIPTOR.services_by_name['DailyBarsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYBARSREQUEST._serialized_start=221
  _DAILYBARSREQUEST._serialized_end=393
  _DAILYBARSRESPONSE._serialized_start=395
  _DAILYBARSRESPONSE._serialized_end=475
  _DAILYBAR._serialized_start=478
  _DAILYBAR._serialized_end=608
  _DAILYBARSSERVICE._serialized_start=611
  _DAILYBARSSERVICE._serialized_end=753
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/quote.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/quote.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"\xd1\x01\n\x05Quote\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12+\n\x05price\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12.\n\tcondition\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x34\n\x04side\x18\x05 \x01(\x0e\x32&.systemathics.apis.type.shared.v1.Sideb\x06proto3')



_QUOTE = DESCRIPTOR.message_types_by_name['Quote']
Quote = _reflection.GeneratedProtocolMessageType('Quote', (_message.Message,), {
  'DESCRIPTOR' : _QUOTE,
  '__module__' : 'systemathics.apis.type.shared.v1.quote_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Quote)
  })
_sym_db.RegisterMessage(Quote)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUOTE._serialized_start=160
  _QUOTE._serialized_end=369
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_trade_condition_statistics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRsystemathics/apis/services/tick_analytics/v1/tick_trade_condition_statistics.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xab\x01\n#TickTradeConditionStatisticsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\xa8\x01\n$TickTradeConditionStatisticsResponse\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\r\n\x05total\x18\x03 \x01(\x03\x12\x12\n\npercentage\x18\x04 \x01(\x01\x12\x0e\n\x06volume\x18\x05 \x01(\x03\x12\x14\n\x0ctotal_volume\x18\x06 \x01(\x03\x12\x19\n\x11volume_percentage\x18\x07 \x01(\x01\x32\xef\x01\n#TickTradeConditionStatisticsService\x12\xc7\x01\n\x1cTickTradeConditionStatistics\x12Q.systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsRequest\x1aR.systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsResponse0\x01\x62\x06proto3')



_TICKTRADECONDITIONSTATISTICSREQUEST = DESCRIPTOR.message_types_by_name['TickTradeConditionStatisticsRequest']
_TICKTRADECONDITIONSTATISTICSRESPONSE = DESCRIPTOR.message_types_by_name['TickTradeConditionStatisticsResponse']
TickTradeConditionStatisticsRequest = _reflection.GeneratedProtocolMessageType('TickTradeConditionStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSTATISTICSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_condition_statistics_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsRequest)
  })
_sym_db.RegisterMessage(TickTradeConditionStatisticsRequest)

TickTradeConditionStatisticsResponse = _reflection.GeneratedProtocolMessageType('TickTradeConditionStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADECONDITIONSTATISTICSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_trade_condition_statistics_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsResponse)
  })
_sym_db.RegisterMessage(TickTradeConditionStatisticsResponse)

_TICKTRADECONDITIONSTATISTICSSERVICE = DESCRIPTOR.services_by_name['TickTradeConditionStatisticsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKTRADECONDITIONSTATISTICSREQUEST._serialized_start=236
  _TICKTRADECONDITIONSTATISTICSREQUEST._serialized_end=407
  _TICKTRADECONDITIONSTATISTICSRESPONSE._serialized_start=410
  _TICKTRADECONDITIONSTATISTICSRESPONSE._serialized_end=578
  _TICKTRADECONDITIONSTATISTICSSERVICE._serialized_start=581
  _TICKTRADECONDITIONSTATISTICSSERVICE._serialized_end=820
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/daily_analytics/v1/daily_bollinger.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xd4\x01\n\x15\x44\x61ilyBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x11\n\tdeviation\x18\x04 \x01(\x01\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"i\n\x16\x44\x61ilyBollingerResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.daily_analytics.v1.DailyBollingerData\"\xcc\x01\n\x12\x44\x61ilyBollingerData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue2\xb7\x01\n\x15\x44\x61ilyBollingerService\x12\x9d\x01\n\x0e\x44\x61ilyBollinger\x12\x44.systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest\x1a\x45.systemathics.apis.services.daily_analytics.v1.DailyBollingerResponseb\x06proto3')



_DAILYBOLLINGERREQUEST = DESCRIPTOR.message_types_by_name['DailyBollingerRequest']
_DAILYBOLLINGERRESPONSE = DESCRIPTOR.message_types_by_name['DailyBollingerResponse']
_DAILYBOLLINGERDATA = DESCRIPTOR.message_types_by_name['DailyBollingerData']
DailyBollingerRequest = _reflection.GeneratedProtocolMessageType('DailyBollingerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBOLLINGERREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest)
  })
_sym_db.RegisterMessage(DailyBollingerRequest)

DailyBollingerResponse = _reflection.GeneratedProtocolMessageType('DailyBollingerResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBOLLINGERRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyBollingerResponse)
  })
_sym_db.RegisterMessage(DailyBollingerResponse)

DailyBollingerData = _reflection.GeneratedProtocolMessageType('DailyBollingerData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBOLLINGERDATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyBollingerData)
  })
_sym_db.RegisterMessage(DailyBollingerData)

_DAILYBOLLINGERSERVICE = DESCRIPTOR.services_by_name['DailyBollingerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYBOLLINGERREQUEST._serialized_start=278
  _DAILYBOLLINGERREQUEST._serialized_end=490
  _DAILYBOLLINGERRESPONSE._serialized_start=492
  _DAILYBOLLINGERRESPONSE._serialized_end=597
  _DAILYBOLLINGERDATA._serialized_start=600
  _DAILYBOLLINGERDATA._serialized_end=804
  _DAILYBOLLINGERSERVICE._serialized_start=807
  _DAILYBOLLINGERSERVICE._serialized_end=990
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/book_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import trade_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2
from systemathics.apis.type.shared.v1 import book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0systemathics/apis/type/shared/v1/book_data.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a,systemathics/apis/type/shared/v1/trade.proto\x1a+systemathics/apis/type/shared/v1/book.proto\"\x81\x01\n\x08\x42ookData\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x04\x62ook\x18\x04 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.Bookb\x06proto3')



_BOOKDATA = DESCRIPTOR.message_types_by_name['BookData']
BookData = _reflection.GeneratedProtocolMessageType('BookData', (_message.Message,), {
  'DESCRIPTOR' : _BOOKDATA,
  '__module__' : 'systemathics.apis.type.shared.v1.book_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.BookData)
  })
_sym_db.RegisterMessage(BookData)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BOOKDATA._serialized_start=211
  _BOOKDATA._serialized_end=340
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/dividends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/corporate_actions/v1/dividends.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x98\x01\n\x10\x44ividendsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\\\n\x11\x44ividendsResponse\x12G\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.corporate_actions.v1.Dividend\"\x97\x01\n\x08\x44ividend\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12K\n\x04type\x18\x02 \x01(\x0e\x32=.systemathics.apis.services.corporate_actions.v1.DividendType\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\r\n\x05score\x18\x04 \x01(\x01*^\n\x0c\x44ividendType\x12\x1d\n\x19\x44IVIDEND_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x44IVIDEND_TYPE_CASH\x10\x01\x12\x17\n\x13\x44IVIDEND_TYPE_STOCK\x10\x02\x32\xa7\x01\n\x10\x44ividendsService\x12\x92\x01\n\tDividends\x12\x41.systemathics.apis.services.corporate_actions.v1.DividendsRequest\x1a\x42.systemathics.apis.services.corporate_actions.v1.DividendsResponseb\x06proto3')

_DIVIDENDTYPE = DESCRIPTOR.enum_types_by_name['DividendType']
DividendType = enum_type_wrapper.EnumTypeWrapper(_DIVIDENDTYPE)
DIVIDEND_TYPE_UNSPECIFIED = 0
DIVIDEND_TYPE_CASH = 1
DIVIDEND_TYPE_STOCK = 2


_DIVIDENDSREQUEST = DESCRIPTOR.message_types_by_name['DividendsRequest']
_DIVIDENDSRESPONSE = DESCRIPTOR.message_types_by_name['DividendsResponse']
_DIVIDEND = DESCRIPTOR.message_types_by_name['Dividend']
DividendsRequest = _reflection.GeneratedProtocolMessageType('DividendsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsRequest)
  })
_sym_db.RegisterMessage(DividendsRequest)

DividendsResponse = _reflection.GeneratedProtocolMessageType('DividendsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsResponse)
  })
_sym_db.RegisterMessage(DividendsResponse)

Dividend = _reflection.GeneratedProtocolMessageType('Dividend', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDEND,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Dividend)
  })
_sym_db.RegisterMessage(Dividend)

_DIVIDENDSSERVICE = DESCRIPTOR.services_by_name['DividendsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DIVIDENDTYPE._serialized_start=646
  _DIVIDENDTYPE._serialized_end=740
  _DIVIDENDSREQUEST._serialized_start=244
  _DIVIDENDSREQUEST._serialized_end=396
  _DIVIDENDSRESPONSE._serialized_start=398
  _DIVIDENDSRESPONSE._serialized_end=490
  _DIVIDEND._serialized_start=493
  _DIVIDEND._serialized_end=644
  _DIVIDENDSSERVICE._serialized_start=743
  _DIVIDENDSSERVICE._serialized_end=910
# @@protoc_insertion_point(module_scope)



import os
import setuptools

from setuptools import setup, find_packages

setup(
    name="systemathics.apis",
    version="0.10.4-pre",
    author="Systemathics",
    author_email="contact@systemathics.com",
    description="Python grpc stub for Systemathics APIs.",
    url="https://github.com/pypa/sampleproject",
    packages=find_packages(),
    namespace_packages=['systemathics'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    license='MIT',
    python_requires='>=3.6',
    install_requires=['googleapis-common-protos', 'protobuf', 'grpcio'],
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/indices/v1/components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/indices/v1/components.proto\x12%systemathics.apis.services.indices.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\'\n\x11\x43omponentsRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"Z\n\x12\x43omponentsResponse\x12\x44\n\ncomponents\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.indices.v1.Component\"]\n\tComponent\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x32\x97\x01\n\x11\x43omponentsService\x12\x81\x01\n\nComponents\x12\x38.systemathics.apis.services.indices.v1.ComponentsRequest\x1a\x39.systemathics.apis.services.indices.v1.ComponentsResponseb\x06proto3')



_COMPONENTSREQUEST = DESCRIPTOR.message_types_by_name['ComponentsRequest']
_COMPONENTSRESPONSE = DESCRIPTOR.message_types_by_name['ComponentsResponse']
_COMPONENT = DESCRIPTOR.message_types_by_name['Component']
ComponentsRequest = _reflection.GeneratedProtocolMessageType('ComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSREQUEST,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.ComponentsRequest)
  })
_sym_db.RegisterMessage(ComponentsRequest)

ComponentsResponse = _reflection.GeneratedProtocolMessageType('ComponentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSRESPONSE,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.ComponentsResponse)
  })
_sym_db.RegisterMessage(ComponentsResponse)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENT,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.Component)
  })
_sym_db.RegisterMessage(Component)

_COMPONENTSSERVICE = DESCRIPTOR.services_by_name['ComponentsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPONENTSREQUEST._serialized_start=224
  _COMPONENTSREQUEST._serialized_end=263
  _COMPONENTSRESPONSE._serialized_start=265
  _COMPONENTSRESPONSE._serialized_end=355
  _COMPONENT._serialized_start=357
  _COMPONENT._serialized_end=450
  _COMPONENTSSERVICE._serialized_start=453
  _COMPONENTSSERVICE._serialized_end=604
# @@protoc_insertion_point(module_scope)
